@@ -3,6 +3,7 @@ from typing import Any, List, Optional
 from uuid import UUID
 
 from pybotx import Bot, File, SmartAppEvent
+from pybotx.missing import Missing, Undefined
 
 
 class SmartApp:
@@ -37,9 +38,10 @@ class SmartApp:
             files=files or [],
         )
 
-    async def update_app_counter(self, counter: int) -> None:
+    async def send_push(self, counter: int, body: Missing[str] = Undefined) -> None:
         await self.bot.send_smartapp_notification(
             bot_id=self.bot_id,
             chat_id=self.chat_id,
             smartapp_counter=counter,
+            body=body,
         )
